@@ -1,10 +1,13 @@
 import datetime
 import logging
 
+import json
+
 from flask import Flask
 from flask import g
 from flask import render_template
 from flask import request
+from flask import Response
 from flask import redirect
 from flask import url_for
 from flask import flash
@@ -51,6 +54,14 @@ def index():
     return render_template('index.html', jobs=jobs, categories=categories)
 
 
+@app.route('/_status')
+def status():
+    return Response(
+        json.dumps({'status': 'OK'}),
+        mimetype='application/json',
+    )
+
+
 @app.route('/job/<int:id>', methods=['GET', 'POST'])
 def job(id):
     if request.method == 'POST' and request.form.get('run_now') is not None:
